@@ -16,6 +16,7 @@ use Statistics::Basic qw(:all);
 use Set::Intersection;
 use List::Compare;
 use IO::Tee;
+use File::Copy qw( move copy );
 use Sim::OPT;
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
@@ -36,7 +37,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.47.11'; # our $VERSION = '';
+$VERSION = '0.49.0'; # our $VERSION = '';
 
 
 #########################################################################################
@@ -75,11 +76,30 @@ sub retrieve
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
-	say "\nNow in Sim::OPT::Report::retrieve.\n";
+	#say "\nNow in Sim::OPT::Report::retrieve.\n";
 	say $tee "\n#Now in Sim::OPT::Report_retrieve.\n";
 	
 	%dowhat = %main::dowhat;
-
+	
+	#my $evalfiletemp = $dowhat{evalfile};
+	#my $evalfile;
+	#unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
+	#{
+	#	$evalfile = $mypath . "/" . $evalfiletemp;
+	#}
+	#else
+	#{
+	#	$evalfile = $mypath . "\\" . $evalfiletemp;
+	#}
+	#say $tee "AS \$evalfile I HAVE $evalfile";
+	#
+	#if ( -e $evalfile )
+	#{
+	#	say $tee "NOW EVALING $evalfile";
+	#	say $tee `cat $evalfile`;
+	#	eval { `cat $evalfile` };
+	#}
+				
 	%simtitles = %main::simtitles; #say $tee "dumpINRETRIEVE(\%simtitles): " . dump(%simtitles);
 	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
@@ -135,7 +155,7 @@ sub retrieve
 	my $countinstance = 0;
 	foreach my $instance (@instances)
 	{
-		say TOFILE "\nNow in Sim::OPT::Retrieve. INSTANCES\n";
+		#say TOFILE "\nNow in Sim::OPT::Retrieve. INSTANCES\n";
 		my %d = %{$instance};
 		my $countcase = $d{countcase}; #say TOFILE "dump(\$countcase): " . dump($countcase);
 		my $countblock = $d{countblock}; #say TOFILE "dump(\$countblock): " . dump($countblock);
@@ -177,15 +197,15 @@ sub retrieve
 					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile ) = @_;
 					my @retrdata = @$retrdata_ref;
 					
-					say "INRETRIEVE0\$countcase : " . dump($countcase);
-					say "INRETRIEVE1\@rootnames : " . dump(@rootnames);
-					say "INRETRIEVE1\$countblock : " . dump($countblock);
-					say "INRETRIEVE1\@sweeps : " . dump(@sweeps);
-					say "INRETRIEVE1\@varinumbers : " . dump(@varinumbers);
-					say "INRETRIEVE1\@miditers : " . dump(@miditers);
-					say "INRETRIEVE1\@winneritems : " . dump(@winneritems);
-					say "INRETRIEVE1\@morphcases : " . dump(@morphcases);
-					say "INRETRIEVE1\@morphstruct : " . dump(@morphstruct);
+					#say "INRETRIEVE0\$countcase : " . dump($countcase);
+					#say "INRETRIEVE1\@rootnames : " . dump(@rootnames);
+					#say "INRETRIEVE1\$countblock : " . dump($countblock);
+					#say "INRETRIEVE1\@sweeps : " . dump(@sweeps);
+					#say "INRETRIEVE1\@varinumbers : " . dump(@varinumbers);
+					#say "INRETRIEVE1\@miditers : " . dump(@miditers);
+					#say "INRETRIEVE1\@winneritems : " . dump(@winneritems);
+					#say "INRETRIEVE1\@morphcases : " . dump(@morphcases);
+					#say "INRETRIEVE1\@morphstruct : " . dump(@morphstruct);
 
 					unless (-e "$retfile-")
 					{
@@ -286,9 +306,9 @@ ZZZ
 				sub retrieve_stats_results
 				{	
 					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ) = @_;
-					print $tee " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
-					print $tee "\%retrievedata: " . dump( %retrievedata ); 
-					my @retrdata = @$retrdata_ref; say $tee "\@retrdata " . dump(@retrdata);
+					#print $tee " IN RETRIEVE STATS: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+					#print $tee "\%retrievedata: " . dump( %retrievedata ); 
+					my @retrdata = @$retrdata_ref; #say $tee "\@retrdata " . dump(@retrdata);
 					my $printthis;
 					
 					if ( $themereport eq "loads" )
@@ -351,7 +371,213 @@ TTT
 
 				}
 				
-				say $tee "\nNow in Sim::OPT::Retrieve. INSIDE";
+				sub retrieve_adhoc
+				{	
+					my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ) = @_;
+					#my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ) = @_;
+					print $tee " IN RETRIEVE ADHOC: \$sim: $sim, \$resfile: $resfile, \$result: $result, \$reporttitle: $reporttitle, \$themereport: $themereport, \$counttheme: $counttheme, \$countreport, $countreport, \$retfile : $retfile \n";
+					#print $tee "\%retrievedata: " . dump( %retrievedata ); 
+					my @retrdata = @$retrdata_ref; #say $tee "\@retrdata " . dump(@retrdata);
+					#my $insert = eval { $adhoclines }; say $tee "\$insert: $insert";
+					my $printthis;
+					if ( $themereport eq "radent" )
+					{
+						$printthis =
+"res -file $resfile -mode script<<TTT
+
+3
+$retrdata[0]
+$retrdata[1]
+$retrdata[2]
+c
+g
+d
+a
+>
+a
+$retfile
+$retfile
+
+!
+-
+-
+-
+-
+-
+TTT
+";
+			
+					print $tee " 
+#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+$printthis
+";
+					
+						if ($exeonfiles eq "y") 
+						{
+							#say "Retrieving $themereport results.";
+							say $tee "#Retrieving $themereport results.";
+							print `$printthis`;
+						}
+					}
+					elsif ( $themereport eq "radabs" )
+					{
+						$printthis =
+"res -file $resfile -mode script<<TTT
+
+3
+$retrdata[0]
+$retrdata[1]
+$retrdata[2]
+c
+g
+d
+c
+>
+a
+$retfile
+$retfile
+
+!
+-
+-
+-
+-
+-
+TTT
+";
+			
+					print $tee " 
+#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+$printthis
+";
+					
+						if ($exeonfiles eq "y") 
+						{
+							#say "Retrieving $themereport results.";
+							say $tee "#Retrieving $themereport results.";
+							print `$printthis`;
+						}
+					}
+					elsif ( $themereport eq "airtemp" )
+					{
+						$printthis =
+"res -file $resfile -mode script<<TTT
+
+3
+$retrdata[0]
+$retrdata[1]
+$retrdata[2]
+c
+g
+b
+e
+>
+a
+$retfile
+$retfile
+
+!
+-
+-
+-
+-
+-
+TTT
+";
+			
+					print $tee " 
+#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+$printthis
+";
+					
+						if ($exeonfiles eq "y") 
+						{
+							#say "Retrieving $themereport results.";
+							say $tee "#Retrieving $themereport results.";
+							print `$printthis`;
+						}
+					}
+					elsif ( $themereport eq "radtemp" )
+					{
+						$printthis =
+"res -file $resfile -mode script<<TTT
+
+3
+$retrdata[0]
+$retrdata[1]
+$retrdata[2]
+c
+g
+b
+e
+>
+a
+$retfile
+$retfile
+
+!
+-
+-
+-
+-
+-
+TTT
+";
+			
+					print $tee " 
+#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+$printthis
+";
+					
+						if ($exeonfiles eq "y") 
+						{
+							#say "Retrieving $themereport results.";
+							say $tee "#Retrieving $themereport results.";
+							print `$printthis`;
+						}
+					}
+					elsif ( $themereport eq "restemp" )
+					{
+						$printthis =
+"res -file $resfile -mode script<<TTT
+
+3
+$retrdata[0]
+$retrdata[1]
+$retrdata[2]
+c
+g
+b
+e
+>
+a
+$retfile
+$retfile
+
+!
+-
+-
+-
+-
+-
+TTT
+";
+			
+					print $tee " 
+#Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n
+$printthis
+";
+					
+						if ($exeonfiles eq "y") 
+						{
+							#say "Retrieving $themereport results.";
+							say $tee "#Retrieving $themereport results.";
+							print `$printthis`;
+						}
+					}
+				}
+				
+				#say $tee "\nNow in Sim::OPT::Retrieve. INSIDE";
 				my @resfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; say $tee "SAY\@resfiles " . dump(@resfiles); 
 				#say $tee "SAY\@simcases " . dump( @simcases ); say $tee "SAY\@simstruct " . dump(@simstruct); 
 				
@@ -363,15 +589,16 @@ TTT
 					if ( $tooltype eq "esp-r" )
 					{
 						my $counttheme = 0;
+						say $tee "INRETRIEVE \@{ \$retrievedata{\$counttool} } " . dump( @{ $retrievedata{$counttool} } );
 						foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
 						{	
-							#say $tee "\$retrievedatum " . dump($retrievedatum);
+							say $tee "INRETRIEVE \$retrievedatum " . dump( $retrievedatum );
 							my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; #say $tee "\$reportdata_ref_ref " . dump($reportdata_ref_ref);
 							my @retrievedatarefs = @{$retrievedatum}; #say $tee "\@retrievedatarefs " . dump(@retrievedatarefs);
 							my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; #say $tee "\$simtitle " . dump($simtitle);
-							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; #say $tee "\@sims " . dump(@sims);
+							my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; say $tee "\@sims " . dump(@sims);
 							
-							my $resfile = $resfiles[ $counttheme ]; #say $tee "\HERE\$resfile " . dump($resfile);
+							my $resfile = $resfiles[ 0 ]; #say $tee "\HERE\$resfile " . dump($resfile);
 							
 							#if ( not ( eval ( $skipreport ) ) )
 							if ( -e $resfile ) 
@@ -413,12 +640,14 @@ TTT
 									#	}
 									#}
 													
-									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say $tee "\$reportdata_ref" . dump($reportdata_ref); 
-									my @reportdata = @$reportdata_ref;  say $tee "\@reportdata" . dump(@reportdata); 
+									my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
+									my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
 									
 									my $countitem = 0;
 									foreach my $item ( @reportdata )
 									{
+										
+										
 										my %datarep = %$item; say $tee "\%datarep" . dump(%datarep); 
 										my $reporttitle = $datarep{reporttitle}; say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
 										my $themereport = $datarep{themereport}; say $tee "\$themereport " . dump($themereport); 
@@ -428,6 +657,7 @@ TTT
 										my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
 										my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
 										my $afterlines = $datarep{afterlines}; say $tee "\$afterlines " . dump($afterlines); 
+										#my $adhoclines = $datarep{adhoclines}; say $tee "\$adhoclines " . dump($adhoclines); 
 										my $retfile = "$resfile-$reporttitle-$themereport.grt"; #say $tee "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
 										
 										$retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem][$counttool] = $retfile;
@@ -452,7 +682,8 @@ TTT
 																					semaphorestop1 => $semaphorestop1,
 																					semaphorestop2 => $semaphorestop2,
 																					textpattern => $textpattern,
-																					afterlines => $afterlines
+																					afterlines => $afterlines,
+																					#adhoclines => $adhoclines,
 																				} );
 										}
 										
@@ -471,6 +702,13 @@ TTT
 											retrieve_stats_results( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
 														$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
 										}
+										elsif ( ( $themereport eq "radent" ) or ( $themereport eq "radabs" ) or ( $themereport eq "airtemp" ) or ( $themereport eq "radtemp" ) or ( $themereport eq "restemp" ) )
+										{ 
+											say $tee "RETRIEVING ADHOC";
+											retrieve_adhoc( $result, $resfile, \@retrdata, $reporttitle, $themereport, $counttheme, 
+														$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ); 
+														#$countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines, $adhoclines ); 
+										}
 										$countitem++;
 									}
 									$countreport++;
@@ -482,7 +720,7 @@ TTT
 					}
 					elsif ( ( $tooltype eq "generic" ) or ( $tooltype eq "energyplus" ) )
 					{	#use warnings; use strict;
-						my @retfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; say $tee "SAY\@retfiles " . dump(@retfiles); 
+						my @retfiles = @{ $simstruct[$countcase][$countblock][$countinstance][$counttool] }; #say $tee "SAY\@retfiles " . dump(@retfiles); 
 						$retstruct[$countcase][$countblock][$countinstance][$counttool]  = $simstruct[$countcase][$countblock][$countinstance][$counttool] ; 
 						my $counttheme = 0;
 						foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
@@ -503,8 +741,8 @@ TTT
 								open( RETLIST, ">>$retlist"); # or die;
 								open( RETBLOCK, ">>$retblock"); # or die;
 																				
-								my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say $tee "\$reportdata_ref" . dump($reportdata_ref); 
-								my @reportdata = @$reportdata_ref;  say $tee "\@reportdata" . dump(@reportdata); 
+								my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "\$reportdata_ref" . dump($reportdata_ref); 
+								my @reportdata = @$reportdata_ref;  #say $tee "\@reportdata" . dump(@reportdata); 
 								
 								my $retfile = "$resfile"; #say $tee "\$retfile " . dump($retfile); 
 								if ( not ($retfile ~~ @retcases ) )
@@ -519,16 +757,16 @@ TTT
 								my $countitem = 0;
 								foreach my $item ( @reportdata )
 								{
-									my %datarep = %$item; say $tee "\%datarep" . dump(%datarep); 
-									my $reporttitle = $datarep{reporttitle}; say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
-									my $themereport = $datarep{themereport}; say $tee "\$themereport " . dump($themereport); 
-									my $semaphorego1 = $datarep{semaphorego1}; say $tee "\$semaphorego1 " . dump($semaphorego1); 
-									my $semaphorego2 = $datarep{semaphorego2}; say $tee "\$semaphorego2 " . dump($semaphorego2); 
-									my $semaphorestop1 = $datarep{semaphorestop1}; say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
-									my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
-									my $textpattern = $datarep{textpattern}; say $tee "\$textpattern " . dump($textpattern); 
-									my $afterlines = $datarep{afterlines}; say $tee "\$afterlines " . dump($afterlines);  
-									say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
+									my %datarep = %$item; #say $tee "\%datarep" . dump(%datarep); 
+									my $reporttitle = $datarep{reporttitle}; #say $tee "\$reporttitle! " . dump($reporttitle); ###DDD HERE
+									my $themereport = $datarep{themereport}; #say $tee "\$themereport " . dump($themereport); 
+									my $semaphorego1 = $datarep{semaphorego1}; #say $tee "\$semaphorego1 " . dump($semaphorego1); 
+									my $semaphorego2 = $datarep{semaphorego2}; #say $tee "\$semaphorego2 " . dump($semaphorego2); 
+									my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "\$semaphorestop1 " . dump($semaphorestop1); 
+									my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "\$semaphorestop2 " . dump($semaphorestop2); 
+									my $textpattern = $datarep{textpattern}; #say $tee "\$textpattern " . dump($textpattern); 
+									my $afterlines = $datarep{afterlines}; #say $tee "\$afterlines " . dump($afterlines);  
+									#say TOFILE "\$retfile " . dump($retfile); say TOFILE "\$retfile " . dump($retfile);
 									
 									print RETBLOCK "$retfile\n";
 	
@@ -567,15 +805,16 @@ TTT
 		}
 		$countinstance++;
 	}
+	
 	print `rm -f $mypath/*.par`;
 	print TOFILE "rm -f $mypath/*.par\n";
 	close OUTFILE;
 	close TOFILE;
 	close RETLIST;
 	close RETBLOCK;
-	say $tee "INEXIT \@retcases " . dump( @retcases ); 
-	say $tee "\@retstruct " . dump( @retstruct ); 
-	say $tee "\@notecases " . dump( @notecases ); 
+	#say $tee "INEXIT \@retcases " . dump( @retcases ); 
+	#say $tee "\@retstruct " . dump( @retstruct ); 
+	#say $tee "\@notecases " . dump( @notecases ); 
 	return ( \@retcases, \@retstruct, \@notecases );
 }	# END SUB RETRIEVE
 
@@ -611,12 +850,12 @@ sub report # This function retrieves the results of interest from the texts file
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!";  
-	say "\nNow in Sim::OPT::Report::report.\n";
-	say TOFILE "\n#Now in Sim::OPT::Report::report.\n";
+	say $tee "\nNow in Sim::OPT::Report::report.\n";
+	#say TOFILE "\n#Now in Sim::OPT::Report::report.\n";
 	
 	%dowhat = %main::dowhat;
 
-	%simtitles = %main::simtitles; say $tee "dumpINRETRIEVE(\%simtitles): " . dump(%simtitles);
+	%simtitles = %main::simtitles; #say $tee "dumpINRETRIEVE(\%simtitles): " . dump(%simtitles);
 	%retrievedata = %main::retrievedata;
 	@keepcolumns = @main::keepcolumns;
 	@weights = @main::weights;
@@ -626,7 +865,7 @@ sub report # This function retrieves the results of interest from the texts file
 	@varthemes_steps = @main::varthemes_steps;
 	@rankdata = @main::rankdata; # CUT ZZZ
 	@rankcolumn = @main::rankcolumn;
-	%reportdata = %main::reportdata; say $tee "dump(\%reportdata): " . dump(%reportdata);
+	%reportdata = %main::reportdata; #say $tee "dump(\%reportdata): " . dump(%reportdata);
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -638,21 +877,21 @@ sub report # This function retrieves the results of interest from the texts file
 	my @simstruct = @{ $dirfiles{simstruct} }; #say "dump(\@simstruct): " . dump(@simstruct);
 	my @INREPORT = @{ $dirfiles{morphcases} };
 	my @morphstruct = @{ $dirfiles{morphstruct} };
-	my @retcases = @{ $dirfiles{retcases} }; say TOFILE "dumpINREPORT::report(\@retcases): " . dump(@retcases); 
-	my @retstruct = @{ $dirfiles{retstruct} }; say TOFILE "dumpINREPORT::report(\@retstruct): " . dump(@retstruct);
+	my @retcases = @{ $dirfiles{retcases} }; #say TOFILE "dumpINREPORT::report(\@retcases): " . dump(@retcases); 
+	my @retstruct = @{ $dirfiles{retstruct} }; #say TOFILE "dumpINREPORT::report(\@retstruct): " . dump(@retstruct);
 	my @repcases = @{ $dirfiles{repcases} };
 	my @repstruct = @{ $dirfiles{repstruct} };
 	my @mergecases = @{ $dirfiles{mergecases} };
 	my @mergestruct = @{ $dirfiles{mergestruct} };
 	my @descendcases = @{ $dirfiles{descendcases} };
 	my @descendstruct = @{ $dirfiles{descendstruct} };
-	my @notecases = @{ $dirfiles{notecases} }; say TOFILE "dumpINREPORT::report(\@notecases): " . dump(@notecases);
+	my @notecases = @{ $dirfiles{notecases} }; #say TOFILE "dumpINREPORT::report(\@notecases): " . dump(@notecases);
 	
 	my $morphlist = $dirfiles{morphlist}; #say "dump(\$dat{morphlist}): " . dump($dat{morphlist});
 	my $morphblock = $dirfiles{morphblock};
 	my $simlist = $dirfiles{simlist}; #say "dump(\$simlist): " . dump($simlist);
 	my $simblock = $dirfiles{simblock};
-	my $retlist = $dirfiles{retlist}; say TOFILE "dumpINREPORT::report(\$retlist): " . dump($retlist); 
+	my $retlist = $dirfiles{retlist}; #say TOFILE "dumpINREPORT::report(\$retlist): " . dump($retlist); 
 	my $retblock = $dirfiles{retblock};
 	my $replist = $dirfiles{replist};
 	my $repblock = $dirfiles{repblock};
@@ -689,18 +928,18 @@ sub report # This function retrieves the results of interest from the texts file
 		my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); #say TOFILE "dump(\$stepsvar): " . dump($stepsvar); 
 		my $varnumber = $countvar; #say TOFILE "dump---(\$varnumber): " . dump($varnumber) . "\n\n";  # LEGACY VARIABLE
 
-		say TOFILE "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
+		say $tee "#Processing reports for case " . ($countcase + 1) . ", block " . ($countblock + 1);
 		
-		open( REPLIST, ">>$replist" ) or die( "$!" ); say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
-		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
+		open( REPLIST, ">>$replist" ) or die( "$!" ); #say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
+		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); #say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
 		
-		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 		{
-			$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
+			$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  #say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
 		}
 		else
 		{
-			$repfile = "$mypath\\$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
+			$repfile = "$mypath\\$file-report-$countcase-$countblock.txt";  #say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
 		}
 		
 		open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
@@ -715,41 +954,41 @@ sub report # This function retrieves the results of interest from the texts file
 
 		#open( REPFILE, ">>$repfile") or die "Can't open $repfile $!";
 		
-		say TOFILE "dump---(\%notecases): " . dump( %notecases ) . "\n\n";  
+		say $tee "INREPORT dump---(\@notecases): " . dump( @notecases ) . "\n\n";  
 		
-		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say $tee "\$numberof_simtools " . dump( $numberof_simtools );
+		my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say $tee "\$numberof_simtools " . dump( $numberof_simtools );
 		
 		my $counttool = 1;
 		while ( $counttool <= $numberof_simtools )
 		{	
-			my $skip = $vals{$countvar}{$counttool}{skip}; say $tee "dumpinsim(\$skip): " . dump($skip);
+			my $skip = $vals{$countvar}{$counttool}{skip}; #say $tee "dumpinsim(\$skip): " . dump($skip);
 			if ( not ( eval ( $skipsim{$counttool} )))
 			{
-				my $tooltype = $dowhat{simtools}{$counttool}; say $tee "\$tooltype " . dump( $tooltype );
-				say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
+				my $tooltype = $dowhat{simtools}{$counttool}; #say $tee "\$tooltype " . dump( $tooltype );
+				#say $tee "\$notecases[ \$countcase ][ \$countblock ][ \$countinstance ][ \$counttool ] } : " . dump( $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] );
 				foreach $ret_ref ( @{ $notecases[ $countcase ][ $countblock ][ $countinstance ][ $counttool ] } )
 				{
-					say $tee "\$ret_ref " . dump( $ret_ref );
-					%retitem = %$ret_ref; say TOFILE "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
-					my $retfile = $retitem{retfile}; say TOFILE "dump---(\$retfile): " . dump($retfile) . "\n\n";  
-					my $reporttitle = $retitem{reporttitle}; say TOFILE "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
-					my $themereport = $retitem{themereport}; say TOFILE "dump---(\$themereport): " . dump($themereport) . "\n\n";  
-					my $semaphorego1 = $retitem{semaphorego1}; say TOFILE "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
-					my $semaphorego2 = $retitem{semaphorego2}; say TOFILE "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
-					my $semaphorestop1 = $retitem{semaphorestop1}; say TOFILE "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
-					my $semaphorestop2 = $retitem{semaphorestop2}; say TOFILE "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
-					my $textpattern = $retitem{textpattern}; say TOFILE "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
-					my $afterlines = $retitem{afterlines}; say TOFILE "dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
+					say $tee "INREPORT \$ret_ref " . dump( $ret_ref );
+					%retitem = %$ret_ref; say $tee "dump---(\@retitem): " . dump(@retitem) . "\n\n";  
+					my $retfile = $retitem{retfile}; say $tee "dump---(\$retfile): " . dump($retfile) . "\n\n";  
+					my $reporttitle = $retitem{reporttitle}; say $tee "dump---(\$reporttitle): " . dump($reporttitle) . "\n\n";  
+					my $themereport = $retitem{themereport}; say $tee "dump---(\$themereport): " . dump($themereport) . "\n\n";  
+					my $semaphorego1 = $retitem{semaphorego1}; say $tee "dump---(\$semaphorego1): " . dump($semaphorego1) . "\n\n";  
+					my $semaphorego2 = $retitem{semaphorego2}; say $tee "dump---(\$semaphorego2): " . dump($semaphorego2) . "\n\n";  
+					my $semaphorestop1 = $retitem{semaphorestop1}; say $tee "dump---(\$semaphorestop1): " . dump($semaphorestop1) . "\n\n";
+					my $semaphorestop2 = $retitem{semaphorestop2}; say $tee "dump---(\$semaphorestop2): " . dump($semaphorestop2) . "\n\n";  
+					my $textpattern = $retitem{textpattern}; say $tee "dump---(\$textpattern): " . dump($textpattern) . "\n\n";  
+					my $afterlines = $retitem{afterlines}; say $tee "INREPORT dump---(\$afterlines): " . dump($afterlines) . "\n\n";  
+					#my $adhoclines = $retitem{adhoclines}; #say $tee "dump---(\$adhoclines): " . dump($adhoclines) . "\n\n";
 					my ( $semaphore1, $semaphore2 );
 					
 					
-					if ( -e $retfile )
-					#if ( not ( eval ( $skipreport ) ) )
+					if ( -e $retfile ) #if ( not ( eval ( $skipreport ) ) )
 					{
 						open( RETFILE, "$retfile" ) or die( "$!" );
 						my @lines = <RETFILE>;
 						close RETFILE;
-						say TOFILE "RETFILE! " ;
+						#say TOFILE "RETFILE! " ;
 						my $countline = 0;
 						foreach my $line ( @lines )
 						{
@@ -760,56 +999,121 @@ sub report # This function retrieves the results of interest from the texts file
 							
 							if ( ( not defined( $semaphorego1 ) ) or ( $line =~ m/$semaphorego1/ ) )
 							{
-								$semaphore1 = "on";  say TOFILE "ON1: ";
+								$semaphore1 = "on";  #say TOFILE "ON1: ";
 							}
 							
 							if ( $semaphore1 eq "on" )
 							{
 								if ( ( not defined( $semaphorego2 ) ) or ( $line =~ m/$semaphorego2/ ) )
 								{
-									$semaphore2 = "on"; say TOFILE "ON2: ";
+									$semaphore2 = "on"; #say TOFILE "ON2: ";
 								}
 							}
 														
 							if ( ( $line =~ m/$semaphorestop1/ ) and ( $semaphorestop1 ne "" ) )
 							{
-								$semaphore1 = "off"; say TOFILE "OFF1: ";
+								$semaphore1 = "off"; #say TOFILE "OFF1: ";
 							}
 							
 							if ( ( $line =~ m/$semaphorestop2/ ) and ( $semaphorestop2 ne "" ) )
 							{
-								$semaphore2 = "off"; say TOFILE "OFF2: ";
+								$semaphore2 = "off"; #say TOFILE "OFF2: ";
 							}
 							
-							if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
+							if ( not ( defined ( $afterlines ) ) )
 							{
-								print TOFILE "HIT REPORT1! "; say TOFILE $line;
-								push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorego1 $semaphorego2 $line " );
-								$semaphore1 = "off";
-								$semaphore2 = "off";
+								say $tee "NOT DEFINED AFTERLINES FOR \$themereport $themereport";
+								if ( ( $textpattern ne "" ) and ( $line =~ m/^$textpattern/ ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
+								{
+									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
+									push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorego1 $semaphorego2 $line " );
+									$semaphore1 = "off";
+									$semaphore2 = "off";
+								}
 							}
-							
-							if ( ( $afterlines ne "" ) and ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) and ( $countline == $afterlines ) )
+							else
 							{
-								print TOFILE "HIT REPORT2! "; say TOFILE $line;
-								push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
-								$countlines = 0;
-								$semaphore1 = "off";
-								$semaphore2 = "off";
-							}
+								say $tee "DEFINED AFTERLINES FOR \$themereport $themereport";
+								if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
+								{
+									#print TOFILE "HIT REPORT1! "; #say TOFILE $line;
+									if ( not ( ref( $afterlines ) ) )
+									{
+										say $tee "NOT REF BUT DEFINED AFTERLINES FOR \$themereport $themereport";
+										if ( ( $afterlines ne "" ) and ( $countline == $afterlines ) )
+										{
+											#print TOFILE "HIT REPORT2! "; #say TOFILE $line;
+											push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
+										}
+									}
+									else
+									{
+										say $tee "REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
+										my @lins = @$afterlines;  say $tee "\@lins @lins";
+										my $countlin = 0;
+										foreach my $lin ( @lins )
+										{	say $tee "FOREACH \$lin: $lin";
+											my $countlocal = 0;
+											unless ( $lin =~ /-/ )
+											{
+												#say $tee "THIS CASE IS ABSENT, ISN'T IT? \$themereport: $themereport";
+												if ( ( $countlocal == 0 ) and ( $countline == $lin ) )
+												{
+													push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
+												}
+												elsif
+												( ( $countlocal > 0 ) and ( $countline == $lin ) )
+												{
+													push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+												}
+												$countlocal++;
+											}
+											else
+											{
+												#say $tee "SPLITTING COUNT FOR REF AND DEFINED AFTERLINES FOR \$themereport $themereport";
+												#my $lin =~ /(.+)-(.+)/ ;
+												#my ( $firstel, $endel ) = ( $1, $2 );
+												my ( $firstel, $endel ) = split( /-/, $lin );
+												
+												my $count = $firstel;
+												while ( $count <= $endel )
+												{
+													if ( ( $count == $firstel ) and ( $count == $countline ) )
+													{
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, "$retfile $semaphorestop1 $semaphorestop2 $line " );
+													}
+													elsif ( ( $count > $firstel ) and ( $count == $countline ) )
+													{
+														push ( @{ $mergestruct[$countcase][$countblock][ $countinstance ] }, " $line " );
+														if ( $count == $endel )
+														{
+															$countline = 0;
+															$semaphore1 = "off";
+															$semaphore2 = "off";
+														}
+													}
+													$count++;
+												}
+											}
+											$countlin++;											
+										}
+									}
+								}
+							}							
 							
 							if ( ( $semaphore1 eq "on" ) and ( $semaphore2 eq "on" ) )
 							{
-								$countline++; say TOFILE "ON3 COUNTLINE: $countline";
+								$countline++; #say TOFILE "ON3 COUNTLINE: $countline";
 							}
 						}
 					}
-					
+					else 
+					{ say $tee "CAN'T FIND NO RES FILE TO OPEN" and die $!; }
 				}
 			}
 			$counttool++;
 		}
-		say TOFILE "\@mergestruct: " . dump(@mergestruct); 
+		#say TOFILE "\@mergestruct: " . dump(@mergestruct); 
 		$countinstance++;
 	}
 	
@@ -825,14 +1129,15 @@ sub report # This function retrieves the results of interest from the texts file
 	{
 		foreach my $inst ( @$instref )
 		{
+			$inst =~ s/ +/ /g ;
 			print REPFILE "$inst"; #say TOFILE " INSTANCE " . dump($_);
 		}
 		print REPFILE "\n";
 	}
 	close REPFILE;
 		
-	say TOFILE "HEREIS \@repcases " . dump(@repcases); say TOFILE "\@repstruct " . dump(@repstruct); say TOFILE "\@mergestruct " . dump(@mergestruct);
-	say TOFILE "\@mergecases " . dump(@mergecases); say TOFILE "\$repfile: " . dump($repfile);
+	#say TOFILE "HEREIS \@repcases " . dump(@repcases); say TOFILE "\@repstruct " . dump(@repstruct); say TOFILE "\@mergestruct " . dump(@mergestruct);
+	#say TOFILE "\@mergecases " . dump(@mergecases); say TOFILE "\$repfile: " . dump($repfile);
 	close TOFILE;
 	close OUTFILE;
 	return ( \@repcases, \@repstruct, \@mergestruct, \@mergecases, $repfile ); 
@@ -846,17 +1151,17 @@ sub get_files # UNUSED. LEGACY. CUT.
 	my ( $themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, 
 		$simtitle, $reporttitle, $simdatum, $retrievsref, $countinstance, $swap, $loadsortemps ) = @_;
 		
-	say TOFILE "#CALLED-REPSTRUCT " . dump(@repstruct); # ZZZ	
-	say TOFILE "CALLED-\$themereport: " . dump($themereport);
-	say TOFILE "CALLED-\$countcase: " . dump($countcase);
-	say TOFILE "CALLED-\$countblock: " . dump($countblock);
-	say TOFILE "CALLED-\$themereport " . dump($themereport);
-	say TOFILE "CALLED-\$counttheme " . dump($counttheme);
-	say TOFILE "CALLED-\$countreport " . dump($countreport);
-	say TOFILE "CALLED-\$retfile: " . dump($retfile);
-	say TOFILE "CALLED-\$repfile: " . dump($repfile);
-	say TOFILE "CALLED-\$loadsortemps " . dump($loadsortemps);
-	say TOFILE "repfilemem CALLED " . dump( @repfilemem );
+	#say TOFILE "#CALLED-REPSTRUCT " . dump(@repstruct); # ZZZ	
+	#say TOFILE "CALLED-\$themereport: " . dump($themereport);
+	#say TOFILE "CALLED-\$countcase: " . dump($countcase);
+	#say TOFILE "CALLED-\$countblock: " . dump($countblock);
+	#say TOFILE "CALLED-\$themereport " . dump($themereport);
+	#say TOFILE "CALLED-\$counttheme " . dump($counttheme);
+	#say TOFILE "CALLED-\$countreport " . dump($countreport);
+	#say TOFILE "CALLED-\$retfile: " . dump($retfile);
+	#say TOFILE "CALLED-\$repfile: " . dump($repfile);
+	#say TOFILE "CALLED-\$loadsortemps " . dump($loadsortemps);
+	#say TOFILE "repfilemem CALLED " . dump( @repfilemem );
 				
 	my @repfilemem = @$swap; #say TOFILE "CALLED-\@repfilemem " . dump(@repfilemem);
 	my @retrievs = @$retrievsref;
@@ -864,9 +1169,9 @@ sub get_files # UNUSED. LEGACY. CUT.
 	my @measurements_to_report = $retrievs[0]; #say TOFILE "CALLED-\@measurements_to_report " . dump(@measurements_to_report);
 	my $dates_to_report = $simtitle; #say TOFILE "CALLED-\$dates_to_report " . dump($dates_to_report);
 	
-	say TOFILE "CALLED\$loadsortemps: " . $loadsortemps; say TOFILE "\$retfile! " . $retfile;
+	#say TOFILE "CALLED\$loadsortemps: " . $loadsortemps; say TOFILE "\$retfile! " . $retfile;
 	open( RETFILE,  "$retfile" ) or die "Can't open $retfile $!";
-	my @lines_to_inspect = <RETFILE>; say TOFILE "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
+	my @lines_to_inspect = <RETFILE>; #say TOFILE "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
 
 	my @countcolumns;
 	my $countzones = 0;
@@ -879,7 +1184,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			$line_to_inspect =~ s/^\s+//g;### DO THIS? ZZZ
 			$line_to_inspect =~ s/\s*$//;      #remove trailing whitespace
 			#$line_to_inspect =~ s/\ {2,}/ /g;  #remove multiple literal spaces
-			$line_to_inspect =~ s/\t{2,}/\t/g; say TOFILE "line_to_inspect: $line_to_inspect";		 
+			$line_to_inspect =~ s/\t{2,}/\t/g; #say TOFILE "line_to_inspect: $line_to_inspect";		 
 			
 			if ( $themereport eq "temps" ) # NEVER CHECKED IF IT STILL WORKS AFTER SOME USES
 			{
@@ -975,7 +1280,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			}
 			
 			my $line_to_report;
-			say TOFILE "\$loadsortemps: $loadsortemps";
+			#say TOFILE "\$loadsortemps: $loadsortemps";
 			if ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats" ) ) 
 			{	
 				if ( $line_to_inspect =~ /^$loadsortemps/ )
@@ -990,7 +1295,7 @@ sub get_files # UNUSED. LEGACY. CUT.
 			}
 		}
 	}
-	say TOFILE "LEAVING \@repfilemem " . dump(@repfilemem);
+	#say TOFILE "LEAVING \@repfilemem " . dump(@repfilemem);
 	return (@repfilemem); 
 } # END SUB get_files
 
